#[non_exhaustive]pub enum HealthCheckFirewallState {
Unspecified,
Configured,
Misconfigured,
UnknownValue(UnknownValue),
}Expand description
State of a health check firewall configuration:
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
State is unspecified. Default state if not populated.
Configured
There are configured firewall rules to allow health check probes to the backend.
Misconfigured
There are firewall rules configured to allow partial health check ranges or block all health check ranges. If a health check probe is sent from denied IP ranges, the health check to the backend will fail. Then, the backend will be marked unhealthy and will not receive traffic sent to the load balancer.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using HealthCheckFirewallState::value or HealthCheckFirewallState::name.
Implementations