#[non_exhaustive]pub struct CloudSQLInstanceInfo {
pub display_name: String,
pub uri: String,
pub network_uri: String,
pub internal_ip: String,
pub external_ip: String,
pub region: String,
/* private fields */
}Expand description
For display only. Metadata associated with a Cloud SQL instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringName of a Cloud SQL instance.
uri: StringURI of a Cloud SQL instance.
network_uri: StringURI of a Cloud SQL instance network or empty string if the instance does not have one.
internal_ip: StringInternal IP address of a Cloud SQL instance.
external_ip: StringExternal IP address of a Cloud SQL instance.
region: StringRegion in which the Cloud SQL instance is running.
Implementations
Sourceimpl CloudSQLInstanceInfo
impl CloudSQLInstanceInfo
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
ⓘ
let x = CloudSQLInstanceInfo::new().set_display_name("example");Sourcepub fn set_network_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_network_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of network_uri.
Example
ⓘ
let x = CloudSQLInstanceInfo::new().set_network_uri("example");Sourcepub fn set_internal_ip<T: Into<String>>(self, v: T) -> Self
pub fn set_internal_ip<T: Into<String>>(self, v: T) -> Self
Sets the value of internal_ip.
Example
ⓘ
let x = CloudSQLInstanceInfo::new().set_internal_ip("example");Sourcepub fn set_external_ip<T: Into<String>>(self, v: T) -> Self
pub fn set_external_ip<T: Into<String>>(self, v: T) -> Self
Sets the value of external_ip.
Example
ⓘ
let x = CloudSQLInstanceInfo::new().set_external_ip("example");Trait Implementations
Sourceimpl Clone for CloudSQLInstanceInfo
impl Clone for CloudSQLInstanceInfo
Sourcefn clone(&self) -> CloudSQLInstanceInfo
fn clone(&self) -> CloudSQLInstanceInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CloudSQLInstanceInfo
impl Debug for CloudSQLInstanceInfo
Sourceimpl Default for CloudSQLInstanceInfo
impl Default for CloudSQLInstanceInfo
Sourcefn default() -> CloudSQLInstanceInfo
fn default() -> CloudSQLInstanceInfo
Returns the “default value” for a type. Read more
Sourceimpl Message for CloudSQLInstanceInfo
impl Message for CloudSQLInstanceInfo
Sourceimpl PartialEq for CloudSQLInstanceInfo
impl PartialEq for CloudSQLInstanceInfo
Sourcefn eq(&self, other: &CloudSQLInstanceInfo) -> bool
fn eq(&self, other: &CloudSQLInstanceInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CloudSQLInstanceInfo