#[non_exhaustive]pub struct CreateVpcFlowLogsConfigRequest {
pub parent: String,
pub vpc_flow_logs_config_id: String,
pub vpc_flow_logs_config: Option<VpcFlowLogsConfig>,
/* private fields */
}Expand description
Request for the CreateVpcFlowLogsConfig method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource of the VpcFlowLogsConfig to create, in one of the following formats:
-
For project-level resources:
projects/{project_id}/locations/global -
For organization-level resources:
organizations/{organization_id}/locations/global
vpc_flow_logs_config_id: StringRequired. ID of the VpcFlowLogsConfig.
vpc_flow_logs_config: Option<VpcFlowLogsConfig>Required. A VpcFlowLogsConfig resource
Implementations
Sourceimpl CreateVpcFlowLogsConfigRequest
impl CreateVpcFlowLogsConfigRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_vpc_flow_logs_config_id<T: Into<String>>(self, v: T) -> Self
pub fn set_vpc_flow_logs_config_id<T: Into<String>>(self, v: T) -> Self
Sets the value of vpc_flow_logs_config_id.
Example
ⓘ
let x = CreateVpcFlowLogsConfigRequest::new().set_vpc_flow_logs_config_id("example");Sourcepub fn set_vpc_flow_logs_config<T>(self, v: T) -> Selfwhere
T: Into<VpcFlowLogsConfig>,
pub fn set_vpc_flow_logs_config<T>(self, v: T) -> Selfwhere
T: Into<VpcFlowLogsConfig>,
Sets the value of vpc_flow_logs_config.
Example
ⓘ
use google_cloud_networkmanagement_v1::model::VpcFlowLogsConfig;
let x = CreateVpcFlowLogsConfigRequest::new().set_vpc_flow_logs_config(VpcFlowLogsConfig::default()/* use setters */);Sourcepub fn set_or_clear_vpc_flow_logs_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<VpcFlowLogsConfig>,
pub fn set_or_clear_vpc_flow_logs_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<VpcFlowLogsConfig>,
Sets or clears the value of vpc_flow_logs_config.
Example
ⓘ
use google_cloud_networkmanagement_v1::model::VpcFlowLogsConfig;
let x = CreateVpcFlowLogsConfigRequest::new().set_or_clear_vpc_flow_logs_config(Some(VpcFlowLogsConfig::default()/* use setters */));
let x = CreateVpcFlowLogsConfigRequest::new().set_or_clear_vpc_flow_logs_config(None::<VpcFlowLogsConfig>);Trait Implementations
Sourceimpl Clone for CreateVpcFlowLogsConfigRequest
impl Clone for CreateVpcFlowLogsConfigRequest
Sourcefn clone(&self) -> CreateVpcFlowLogsConfigRequest
fn clone(&self) -> CreateVpcFlowLogsConfigRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateVpcFlowLogsConfigRequest
impl Default for CreateVpcFlowLogsConfigRequest
Sourcefn default() -> CreateVpcFlowLogsConfigRequest
fn default() -> CreateVpcFlowLogsConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateVpcFlowLogsConfigRequest
impl PartialEq for CreateVpcFlowLogsConfigRequest
Sourcefn eq(&self, other: &CreateVpcFlowLogsConfigRequest) -> bool
fn eq(&self, other: &CreateVpcFlowLogsConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateVpcFlowLogsConfigRequest