EndpointInfo

Struct EndpointInfo 

#[non_exhaustive]
pub struct EndpointInfo { pub source_ip: String, pub destination_ip: String, pub protocol: String, pub source_port: i32, pub destination_port: i32, pub source_network_uri: String, pub destination_network_uri: String, pub source_agent_uri: String, /* private fields */ }
For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
source_ip: String

Source IP address.

destination_ip: String

Destination IP address.

protocol: String

IP protocol in string format, for example: “TCP”, “UDP”, “ICMP”.

source_port: i32

Source port. Only valid when protocol is TCP or UDP.

destination_port: i32

Destination port. Only valid when protocol is TCP or UDP.

source_network_uri: String

URI of the network where this packet originates from.

destination_network_uri: String

URI of the network where this packet is sent to.

source_agent_uri: String

URI of the source telemetry agent this packet originates from.

Implementations

Source

impl EndpointInfo

pub fn new() -> Self

Creates a new default instance.

pub fn set_source_ip<T: Into<String>>(self, v: T) -> Self

Sets the value of source_ip.

Example
let x = EndpointInfo::new().set_source_ip("example");
pub fn set_destination_ip<T: Into<String>>(self, v: T) -> Self

Sets the value of destination_ip.

Example
let x = EndpointInfo::new().set_destination_ip("example");
pub fn set_protocol<T: Into<String>>(self, v: T) -> Self

Sets the value of protocol.

Example
let x = EndpointInfo::new().set_protocol("example");
pub fn set_source_port<T: Into<i32>>(self, v: T) -> Self

Sets the value of source_port.

Example
let x = EndpointInfo::new().set_source_port(42);
pub fn set_destination_port<T: Into<i32>>(self, v: T) -> Self

Sets the value of destination_port.

Example
let x = EndpointInfo::new().set_destination_port(42);
pub fn set_source_network_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of source_network_uri.

Example
let x = EndpointInfo::new().set_source_network_uri("example");
pub fn set_destination_network_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of destination_network_uri.

Example
let x = EndpointInfo::new().set_destination_network_uri("example");
pub fn set_source_agent_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of source_agent_uri.

Example
let x = EndpointInfo::new().set_source_agent_uri("example");