#[non_exhaustive]pub struct FirewallInfo {Show 13 fields
pub display_name: String,
pub uri: String,
pub direction: String,
pub action: String,
pub priority: i32,
pub network_uri: String,
pub target_tags: Vec<String>,
pub target_service_accounts: Vec<String>,
pub policy: String,
pub policy_uri: String,
pub firewall_rule_type: FirewallRuleType,
pub policy_priority: i32,
pub target_type: TargetType,
/* private fields */
}Expand description
For display only. Metadata associated with a VPC firewall rule, an implied VPC firewall rule, or a firewall policy rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringThe display name of the firewall rule. This field might be empty for firewall policy rules.
uri: StringThe URI of the firewall rule. This field is not applicable to implied VPC firewall rules.
direction: StringPossible values: INGRESS, EGRESS
action: StringPossible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP
priority: i32The priority of the firewall rule.
network_uri: StringThe URI of the VPC network that the firewall rule is associated with. This field is not applicable to hierarchical firewall policy rules.
The target tags defined by the VPC firewall rule. This field is not applicable to firewall policy rules.
target_service_accounts: Vec<String>The target service accounts specified by the firewall rule.
policy: StringThe name of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules.
policy_uri: StringThe URI of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules.
firewall_rule_type: FirewallRuleTypeThe firewall rule’s type.
policy_priority: i32The priority of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules.
target_type: TargetTypeTarget type of the firewall rule.
Implementations
Sourceimpl FirewallInfo
impl FirewallInfo
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_direction<T: Into<String>>(self, v: T) -> Self
pub fn set_direction<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_action<T: Into<String>>(self, v: T) -> Self
pub fn set_action<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_priority<T: Into<i32>>(self, v: T) -> Self
pub fn set_priority<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_network_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_network_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of target_tags.
Example
let x = FirewallInfo::new().set_target_tags(["a", "b", "c"]);Sourcepub fn set_target_service_accounts<T, V>(self, v: T) -> Self
pub fn set_target_service_accounts<T, V>(self, v: T) -> Self
Sets the value of target_service_accounts.
Example
let x = FirewallInfo::new().set_target_service_accounts(["a", "b", "c"]);Sourcepub fn set_policy<T: Into<String>>(self, v: T) -> Self
pub fn set_policy<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_policy_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_policy_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_firewall_rule_type<T: Into<FirewallRuleType>>(self, v: T) -> Self
pub fn set_firewall_rule_type<T: Into<FirewallRuleType>>(self, v: T) -> Self
Sets the value of firewall_rule_type.
Example
use google_cloud_networkmanagement_v1::model::firewall_info::FirewallRuleType;
let x0 = FirewallInfo::new().set_firewall_rule_type(FirewallRuleType::HierarchicalFirewallPolicyRule);
let x1 = FirewallInfo::new().set_firewall_rule_type(FirewallRuleType::VpcFirewallRule);
let x2 = FirewallInfo::new().set_firewall_rule_type(FirewallRuleType::ImpliedVpcFirewallRule);Sourcepub fn set_policy_priority<T: Into<i32>>(self, v: T) -> Self
pub fn set_policy_priority<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_target_type<T: Into<TargetType>>(self, v: T) -> Self
pub fn set_target_type<T: Into<TargetType>>(self, v: T) -> Self
Sets the value of target_type.
Example
use google_cloud_networkmanagement_v1::model::firewall_info::TargetType;
let x0 = FirewallInfo::new().set_target_type(TargetType::Instances);
let x1 = FirewallInfo::new().set_target_type(TargetType::InternalManagedLb);Trait Implementations
Sourceimpl Clone for FirewallInfo
impl Clone for FirewallInfo
Sourcefn clone(&self) -> FirewallInfo
fn clone(&self) -> FirewallInfo
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for FirewallInfo
impl Debug for FirewallInfo
Sourceimpl Default for FirewallInfo
impl Default for FirewallInfo
Sourcefn default() -> FirewallInfo
fn default() -> FirewallInfo
Sourceimpl Message for FirewallInfo
impl Message for FirewallInfo
Sourceimpl PartialEq for FirewallInfo
impl PartialEq for FirewallInfo
Sourcefn eq(&self, other: &FirewallInfo) -> bool
fn eq(&self, other: &FirewallInfo) -> bool
self and other values to be equal, and is used by ==.