#[non_exhaustive]pub struct ForwardingRuleInfo {
pub display_name: String,
pub uri: String,
pub matched_protocol: String,
pub matched_port_range: String,
pub vip: String,
pub target: String,
pub network_uri: String,
pub region: String,
pub load_balancer_name: String,
pub psc_service_attachment_uri: String,
pub psc_google_api_target: String,
/* private fields */
}Expand description
For display only. Metadata associated with a Compute Engine forwarding rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringName of the forwarding rule.
uri: StringURI of the forwarding rule.
matched_protocol: StringProtocol defined in the forwarding rule that matches the packet.
matched_port_range: StringPort range defined in the forwarding rule that matches the packet.
vip: StringVIP of the forwarding rule.
target: StringTarget type of the forwarding rule.
network_uri: StringNetwork URI.
region: StringRegion of the forwarding rule. Set only for regional forwarding rules.
load_balancer_name: StringName of the load balancer the forwarding rule belongs to. Empty for forwarding rules not related to load balancers (like PSC forwarding rules).
psc_service_attachment_uri: StringURI of the PSC service attachment this forwarding rule targets (if applicable).
psc_google_api_target: StringPSC Google API target this forwarding rule targets (if applicable).
Implementations
Sourceimpl ForwardingRuleInfo
impl ForwardingRuleInfo
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = ForwardingRuleInfo::new().set_display_name("example");Sourcepub fn set_matched_protocol<T: Into<String>>(self, v: T) -> Self
pub fn set_matched_protocol<T: Into<String>>(self, v: T) -> Self
Sets the value of matched_protocol.
Example
let x = ForwardingRuleInfo::new().set_matched_protocol("example");Sourcepub fn set_matched_port_range<T: Into<String>>(self, v: T) -> Self
pub fn set_matched_port_range<T: Into<String>>(self, v: T) -> Self
Sets the value of matched_port_range.
Example
let x = ForwardingRuleInfo::new().set_matched_port_range("example");Sourcepub fn set_target<T: Into<String>>(self, v: T) -> Self
pub fn set_target<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_network_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_network_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of network_uri.
Example
let x = ForwardingRuleInfo::new().set_network_uri("example");Sourcepub fn set_region<T: Into<String>>(self, v: T) -> Self
pub fn set_region<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_load_balancer_name<T: Into<String>>(self, v: T) -> Self
pub fn set_load_balancer_name<T: Into<String>>(self, v: T) -> Self
Sets the value of load_balancer_name.
Example
let x = ForwardingRuleInfo::new().set_load_balancer_name("example");Sourcepub fn set_psc_service_attachment_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_psc_service_attachment_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of psc_service_attachment_uri.
Example
let x = ForwardingRuleInfo::new().set_psc_service_attachment_uri("example");Sourcepub fn set_psc_google_api_target<T: Into<String>>(self, v: T) -> Self
pub fn set_psc_google_api_target<T: Into<String>>(self, v: T) -> Self
Sets the value of psc_google_api_target.
Example
let x = ForwardingRuleInfo::new().set_psc_google_api_target("example");Trait Implementations
Sourceimpl Clone for ForwardingRuleInfo
impl Clone for ForwardingRuleInfo
Sourcefn clone(&self) -> ForwardingRuleInfo
fn clone(&self) -> ForwardingRuleInfo
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ForwardingRuleInfo
impl Debug for ForwardingRuleInfo
Sourceimpl Default for ForwardingRuleInfo
impl Default for ForwardingRuleInfo
Sourcefn default() -> ForwardingRuleInfo
fn default() -> ForwardingRuleInfo
Sourceimpl Message for ForwardingRuleInfo
impl Message for ForwardingRuleInfo
Sourceimpl PartialEq for ForwardingRuleInfo
impl PartialEq for ForwardingRuleInfo
Sourcefn eq(&self, other: &ForwardingRuleInfo) -> bool
fn eq(&self, other: &ForwardingRuleInfo) -> bool
self and other values to be equal, and is used by ==.