#[non_exhaustive]pub struct GoogleServiceInfo {
pub source_ip: String,
pub google_service_type: GoogleServiceType,
/* private fields */
}Expand description
For display only. Details of a Google Service sending packets to a VPC network. Although the source IP might be a publicly routable address, some Google Services use special routes within Google production infrastructure to reach Compute Engine Instances. https://cloud.google.com/vpc/docs/routes#special_return_paths
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_ip: StringSource IP address.
google_service_type: GoogleServiceTypeRecognized type of a Google Service.
Implementations
Sourceimpl GoogleServiceInfo
impl GoogleServiceInfo
Sourcepub fn set_source_ip<T: Into<String>>(self, v: T) -> Self
pub fn set_source_ip<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_google_service_type<T: Into<GoogleServiceType>>(self, v: T) -> Self
pub fn set_google_service_type<T: Into<GoogleServiceType>>(self, v: T) -> Self
Sets the value of google_service_type.
Example
ⓘ
use google_cloud_networkmanagement_v1::model::google_service_info::GoogleServiceType;
let x0 = GoogleServiceInfo::new().set_google_service_type(GoogleServiceType::Iap);
let x1 = GoogleServiceInfo::new().set_google_service_type(GoogleServiceType::GfeProxyOrHealthCheckProber);
let x2 = GoogleServiceInfo::new().set_google_service_type(GoogleServiceType::CloudDns);Trait Implementations
Sourceimpl Clone for GoogleServiceInfo
impl Clone for GoogleServiceInfo
Sourcefn clone(&self) -> GoogleServiceInfo
fn clone(&self) -> GoogleServiceInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GoogleServiceInfo
impl Debug for GoogleServiceInfo
Sourceimpl Default for GoogleServiceInfo
impl Default for GoogleServiceInfo
Sourcefn default() -> GoogleServiceInfo
fn default() -> GoogleServiceInfo
Returns the “default value” for a type. Read more
Sourceimpl Message for GoogleServiceInfo
impl Message for GoogleServiceInfo
Sourceimpl PartialEq for GoogleServiceInfo
impl PartialEq for GoogleServiceInfo
Sourcefn eq(&self, other: &GoogleServiceInfo) -> bool
fn eq(&self, other: &GoogleServiceInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GoogleServiceInfo