#[non_exhaustive]pub struct ListVpcFlowLogsConfigsResponse {
pub vpc_flow_logs_configs: Vec<VpcFlowLogsConfig>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response for the ListVpcFlowLogsConfigs method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vpc_flow_logs_configs: Vec<VpcFlowLogsConfig>List of VPC Flow Log configurations.
next_page_token: StringPage token to fetch the next set of configurations.
unreachable: Vec<String>Locations that could not be reached (when querying all locations with -).
Implementations
Sourceimpl ListVpcFlowLogsConfigsResponse
impl ListVpcFlowLogsConfigsResponse
Sourcepub fn set_vpc_flow_logs_configs<T, V>(self, v: T) -> Self
pub fn set_vpc_flow_logs_configs<T, V>(self, v: T) -> Self
Sets the value of vpc_flow_logs_configs.
Example
ⓘ
use google_cloud_networkmanagement_v1::model::VpcFlowLogsConfig;
let x = ListVpcFlowLogsConfigsResponse::new()
.set_vpc_flow_logs_configs([
VpcFlowLogsConfig::default()/* use setters */,
VpcFlowLogsConfig::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListVpcFlowLogsConfigsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListVpcFlowLogsConfigsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListVpcFlowLogsConfigsResponse
impl Clone for ListVpcFlowLogsConfigsResponse
Sourcefn clone(&self) -> ListVpcFlowLogsConfigsResponse
fn clone(&self) -> ListVpcFlowLogsConfigsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListVpcFlowLogsConfigsResponse
impl Default for ListVpcFlowLogsConfigsResponse
Sourcefn default() -> ListVpcFlowLogsConfigsResponse
fn default() -> ListVpcFlowLogsConfigsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListVpcFlowLogsConfigsResponse
impl PartialEq for ListVpcFlowLogsConfigsResponse
Sourcefn eq(&self, other: &ListVpcFlowLogsConfigsResponse) -> bool
fn eq(&self, other: &ListVpcFlowLogsConfigsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListVpcFlowLogsConfigsResponse