#[non_exhaustive]pub struct LoadBalancerBackend {
pub display_name: String,
pub uri: String,
pub health_check_firewall_state: HealthCheckFirewallState,
pub health_check_allowing_firewall_rules: Vec<String>,
pub health_check_blocking_firewall_rules: Vec<String>,
/* private fields */
}Expand description
For display only. Metadata associated with a specific load balancer backend.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringName of a Compute Engine instance or network endpoint.
uri: StringURI of a Compute Engine instance or network endpoint.
health_check_firewall_state: HealthCheckFirewallStateState of the health check firewall configuration.
health_check_allowing_firewall_rules: Vec<String>A list of firewall rule URIs allowing probes from health check IP ranges.
health_check_blocking_firewall_rules: Vec<String>A list of firewall rule URIs blocking probes from health check IP ranges.
Implementations
Sourceimpl LoadBalancerBackend
impl LoadBalancerBackend
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
ⓘ
let x = LoadBalancerBackend::new().set_display_name("example");Sourcepub fn set_health_check_firewall_state<T: Into<HealthCheckFirewallState>>(
self,
v: T,
) -> Self
pub fn set_health_check_firewall_state<T: Into<HealthCheckFirewallState>>( self, v: T, ) -> Self
Sets the value of health_check_firewall_state.
Example
ⓘ
use google_cloud_networkmanagement_v1::model::load_balancer_backend::HealthCheckFirewallState;
let x0 = LoadBalancerBackend::new().set_health_check_firewall_state(HealthCheckFirewallState::Configured);
let x1 = LoadBalancerBackend::new().set_health_check_firewall_state(HealthCheckFirewallState::Misconfigured);Sourcepub fn set_health_check_allowing_firewall_rules<T, V>(self, v: T) -> Self
pub fn set_health_check_allowing_firewall_rules<T, V>(self, v: T) -> Self
Sets the value of health_check_allowing_firewall_rules.
Example
ⓘ
let x = LoadBalancerBackend::new().set_health_check_allowing_firewall_rules(["a", "b", "c"]);Sourcepub fn set_health_check_blocking_firewall_rules<T, V>(self, v: T) -> Self
pub fn set_health_check_blocking_firewall_rules<T, V>(self, v: T) -> Self
Sets the value of health_check_blocking_firewall_rules.
Example
ⓘ
let x = LoadBalancerBackend::new().set_health_check_blocking_firewall_rules(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for LoadBalancerBackend
impl Clone for LoadBalancerBackend
Sourcefn clone(&self) -> LoadBalancerBackend
fn clone(&self) -> LoadBalancerBackend
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoadBalancerBackend
impl Debug for LoadBalancerBackend
Sourceimpl Default for LoadBalancerBackend
impl Default for LoadBalancerBackend
Sourcefn default() -> LoadBalancerBackend
fn default() -> LoadBalancerBackend
Returns the “default value” for a type. Read more
Sourceimpl Message for LoadBalancerBackend
impl Message for LoadBalancerBackend
Sourceimpl PartialEq for LoadBalancerBackend
impl PartialEq for LoadBalancerBackend
Sourcefn eq(&self, other: &LoadBalancerBackend) -> bool
fn eq(&self, other: &LoadBalancerBackend) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LoadBalancerBackend