LoadBalancerBackendInfo

Struct LoadBalancerBackendInfo 

#[non_exhaustive]
pub struct LoadBalancerBackendInfo { pub name: String, pub instance_uri: String, pub backend_service_uri: String, pub instance_group_uri: String, pub network_endpoint_group_uri: String, pub backend_bucket_uri: String, pub psc_service_attachment_uri: String, pub psc_google_api_target: String, pub health_check_uri: String, pub health_check_firewalls_config_state: HealthCheckFirewallsConfigState, /* private fields */ }
For display only. Metadata associated with the load balancer backend.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Display name of the backend. For example, it might be an instance name for the instance group backends, or an IP address and port for zonal network endpoint group backends.

instance_uri: String

URI of the backend instance (if applicable). Populated for instance group backends, and zonal NEG backends.

backend_service_uri: String

URI of the backend service this backend belongs to (if applicable).

instance_group_uri: String

URI of the instance group this backend belongs to (if applicable).

network_endpoint_group_uri: String

URI of the network endpoint group this backend belongs to (if applicable).

backend_bucket_uri: String

URI of the backend bucket this backend targets (if applicable).

psc_service_attachment_uri: String

URI of the PSC service attachment this PSC NEG backend targets (if applicable).

psc_google_api_target: String

PSC Google API target this PSC NEG backend targets (if applicable).

health_check_uri: String

URI of the health check attached to this backend (if applicable).

health_check_firewalls_config_state: HealthCheckFirewallsConfigState

Output only. Health check firewalls configuration state for the backend. This is a result of the static firewall analysis (verifying that health check traffic from required IP ranges to the backend is allowed or not). The backend might still be unhealthy even if these firewalls are configured. Please refer to the documentation for more information: https://cloud.google.com/load-balancing/docs/firewall-rules

Implementations

Source

impl LoadBalancerBackendInfo

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = LoadBalancerBackendInfo::new().set_name("example");
pub fn set_instance_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of instance_uri.

Example
let x = LoadBalancerBackendInfo::new().set_instance_uri("example");
pub fn set_backend_service_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of backend_service_uri.

Example
let x = LoadBalancerBackendInfo::new().set_backend_service_uri("example");
pub fn set_instance_group_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of instance_group_uri.

Example
let x = LoadBalancerBackendInfo::new().set_instance_group_uri("example");
pub fn set_network_endpoint_group_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of network_endpoint_group_uri.

Example
let x = LoadBalancerBackendInfo::new().set_network_endpoint_group_uri("example");
pub fn set_backend_bucket_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of backend_bucket_uri.

Example
let x = LoadBalancerBackendInfo::new().set_backend_bucket_uri("example");
pub fn set_psc_service_attachment_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of psc_service_attachment_uri.

Example
let x = LoadBalancerBackendInfo::new().set_psc_service_attachment_uri("example");
pub fn set_psc_google_api_target<T: Into<String>>(self, v: T) -> Self

Sets the value of psc_google_api_target.

Example
let x = LoadBalancerBackendInfo::new().set_psc_google_api_target("example");
pub fn set_health_check_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of health_check_uri.

Example
let x = LoadBalancerBackendInfo::new().set_health_check_uri("example");
pub fn set_health_check_firewalls_config_state<T: Into<HealthCheckFirewallsConfigState>>( self, v: T, ) -> Self

Sets the value of health_check_firewalls_config_state.

Example
use google_cloud_networkmanagement_v1::model::load_balancer_backend_info::HealthCheckFirewallsConfigState;
let x0 = LoadBalancerBackendInfo::new().set_health_check_firewalls_config_state(HealthCheckFirewallsConfigState::FirewallsConfigured);
let x1 = LoadBalancerBackendInfo::new().set_health_check_firewalls_config_state(HealthCheckFirewallsConfigState::FirewallsPartiallyConfigured);
let x2 = LoadBalancerBackendInfo::new().set_health_check_firewalls_config_state(HealthCheckFirewallsConfigState::FirewallsNotConfigured);