#[non_exhaustive]pub struct LoadBalancerInfo {
pub load_balancer_type: LoadBalancerType,
pub health_check_uri: String,
pub backends: Vec<LoadBalancerBackend>,
pub backend_type: BackendType,
pub backend_uri: String,
/* private fields */
}Expand description
For display only. Metadata associated with a load balancer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.load_balancer_type: LoadBalancerTypeType of the load balancer.
health_check_uri: String👎Deprecated
URI of the health check for the load balancer. Deprecated and no longer populated as different load balancer backends might have different health checks.
backends: Vec<LoadBalancerBackend>Information for the loadbalancer backends.
backend_type: BackendTypeType of load balancer’s backend configuration.
backend_uri: StringBackend configuration URI.
Implementations
Sourceimpl LoadBalancerInfo
impl LoadBalancerInfo
Sourcepub fn set_load_balancer_type<T: Into<LoadBalancerType>>(self, v: T) -> Self
pub fn set_load_balancer_type<T: Into<LoadBalancerType>>(self, v: T) -> Self
Sets the value of load_balancer_type.
Example
ⓘ
use google_cloud_networkmanagement_v1::model::load_balancer_info::LoadBalancerType;
let x0 = LoadBalancerInfo::new().set_load_balancer_type(LoadBalancerType::InternalTcpUdp);
let x1 = LoadBalancerInfo::new().set_load_balancer_type(LoadBalancerType::NetworkTcpUdp);
let x2 = LoadBalancerInfo::new().set_load_balancer_type(LoadBalancerType::HttpProxy);Sourcepub fn set_health_check_uri<T: Into<String>>(self, v: T) -> Self
👎Deprecated
pub fn set_health_check_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of health_check_uri.
Example
ⓘ
let x = LoadBalancerInfo::new().set_health_check_uri("example");Sourcepub fn set_backends<T, V>(self, v: T) -> Self
pub fn set_backends<T, V>(self, v: T) -> Self
Sourcepub fn set_backend_type<T: Into<BackendType>>(self, v: T) -> Self
pub fn set_backend_type<T: Into<BackendType>>(self, v: T) -> Self
Sets the value of backend_type.
Example
ⓘ
use google_cloud_networkmanagement_v1::model::load_balancer_info::BackendType;
let x0 = LoadBalancerInfo::new().set_backend_type(BackendType::BackendService);
let x1 = LoadBalancerInfo::new().set_backend_type(BackendType::TargetPool);
let x2 = LoadBalancerInfo::new().set_backend_type(BackendType::TargetInstance);Sourcepub fn set_backend_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_backend_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of backend_uri.
Example
ⓘ
let x = LoadBalancerInfo::new().set_backend_uri("example");Trait Implementations
Sourceimpl Clone for LoadBalancerInfo
impl Clone for LoadBalancerInfo
Sourcefn clone(&self) -> LoadBalancerInfo
fn clone(&self) -> LoadBalancerInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoadBalancerInfo
impl Debug for LoadBalancerInfo
Sourceimpl Default for LoadBalancerInfo
impl Default for LoadBalancerInfo
Sourcefn default() -> LoadBalancerInfo
fn default() -> LoadBalancerInfo
Returns the “default value” for a type. Read more
Sourceimpl Message for LoadBalancerInfo
impl Message for LoadBalancerInfo
Sourceimpl PartialEq for LoadBalancerInfo
impl PartialEq for LoadBalancerInfo
Sourcefn eq(&self, other: &LoadBalancerInfo) -> bool
fn eq(&self, other: &LoadBalancerInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LoadBalancerInfo