#[non_exhaustive]pub struct NetworkInfo {
pub display_name: String,
pub uri: String,
pub matched_subnet_uri: String,
pub matched_ip_range: String,
pub region: String,
/* private fields */
}Expand description
For display only. Metadata associated with a Compute Engine network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringName of a Compute Engine network.
uri: StringURI of a Compute Engine network.
matched_subnet_uri: StringURI of the subnet matching the source IP address of the test.
matched_ip_range: StringThe IP range of the subnet matching the source IP address of the test.
region: StringThe region of the subnet matching the source IP address of the test.
Implementations
Sourceimpl NetworkInfo
impl NetworkInfo
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_matched_subnet_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_matched_subnet_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of matched_subnet_uri.
Example
ⓘ
let x = NetworkInfo::new().set_matched_subnet_uri("example");Sourcepub fn set_matched_ip_range<T: Into<String>>(self, v: T) -> Self
pub fn set_matched_ip_range<T: Into<String>>(self, v: T) -> Self
Sets the value of matched_ip_range.
Example
ⓘ
let x = NetworkInfo::new().set_matched_ip_range("example");Trait Implementations
Sourceimpl Clone for NetworkInfo
impl Clone for NetworkInfo
Sourcefn clone(&self) -> NetworkInfo
fn clone(&self) -> NetworkInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NetworkInfo
impl Debug for NetworkInfo
Sourceimpl Default for NetworkInfo
impl Default for NetworkInfo
Sourcefn default() -> NetworkInfo
fn default() -> NetworkInfo
Returns the “default value” for a type. Read more
Sourceimpl Message for NetworkInfo
impl Message for NetworkInfo
Sourceimpl PartialEq for NetworkInfo
impl PartialEq for NetworkInfo
Sourcefn eq(&self, other: &NetworkInfo) -> bool
fn eq(&self, other: &NetworkInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NetworkInfo