#[non_exhaustive]pub struct RedisClusterInfo {
pub display_name: String,
pub uri: String,
pub network_uri: String,
pub discovery_endpoint_ip_address: String,
pub secondary_endpoint_ip_address: String,
pub location: String,
/* private fields */
}Expand description
For display only. Metadata associated with a Redis Cluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringName of a Redis Cluster.
uri: StringURI of a Redis Cluster in format “projects/{project_id}/locations/{location}/clusters/{cluster_id}”
network_uri: StringURI of the network containing the Redis Cluster endpoints in format “projects/{project_id}/global/networks/{network_id}”.
discovery_endpoint_ip_address: StringDiscovery endpoint IP address of a Redis Cluster.
secondary_endpoint_ip_address: StringSecondary endpoint IP address of a Redis Cluster.
location: StringName of the region in which the Redis Cluster is defined. For example, “us-central1”.
Implementations
Sourceimpl RedisClusterInfo
impl RedisClusterInfo
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
ⓘ
let x = RedisClusterInfo::new().set_display_name("example");Sourcepub fn set_network_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_network_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of network_uri.
Example
ⓘ
let x = RedisClusterInfo::new().set_network_uri("example");Sourcepub fn set_discovery_endpoint_ip_address<T: Into<String>>(self, v: T) -> Self
pub fn set_discovery_endpoint_ip_address<T: Into<String>>(self, v: T) -> Self
Sets the value of discovery_endpoint_ip_address.
Example
ⓘ
let x = RedisClusterInfo::new().set_discovery_endpoint_ip_address("example");Sourcepub fn set_secondary_endpoint_ip_address<T: Into<String>>(self, v: T) -> Self
pub fn set_secondary_endpoint_ip_address<T: Into<String>>(self, v: T) -> Self
Sets the value of secondary_endpoint_ip_address.
Example
ⓘ
let x = RedisClusterInfo::new().set_secondary_endpoint_ip_address("example");Trait Implementations
Sourceimpl Clone for RedisClusterInfo
impl Clone for RedisClusterInfo
Sourcefn clone(&self) -> RedisClusterInfo
fn clone(&self) -> RedisClusterInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RedisClusterInfo
impl Debug for RedisClusterInfo
Sourceimpl Default for RedisClusterInfo
impl Default for RedisClusterInfo
Sourcefn default() -> RedisClusterInfo
fn default() -> RedisClusterInfo
Returns the “default value” for a type. Read more
Sourceimpl Message for RedisClusterInfo
impl Message for RedisClusterInfo
Sourceimpl PartialEq for RedisClusterInfo
impl PartialEq for RedisClusterInfo
Sourcefn eq(&self, other: &RedisClusterInfo) -> bool
fn eq(&self, other: &RedisClusterInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RedisClusterInfo