#[non_exhaustive]pub struct RedisInstanceInfo {
pub display_name: String,
pub uri: String,
pub network_uri: String,
pub primary_endpoint_ip: String,
pub read_endpoint_ip: String,
pub region: String,
/* private fields */
}Expand description
For display only. Metadata associated with a Cloud Redis Instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringName of a Cloud Redis Instance.
uri: StringURI of a Cloud Redis Instance.
network_uri: StringURI of a Cloud Redis Instance network.
primary_endpoint_ip: StringPrimary endpoint IP address of a Cloud Redis Instance.
read_endpoint_ip: StringRead endpoint IP address of a Cloud Redis Instance (if applicable).
region: StringRegion in which the Cloud Redis Instance is defined.
Implementations
Sourceimpl RedisInstanceInfo
impl RedisInstanceInfo
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
ⓘ
let x = RedisInstanceInfo::new().set_display_name("example");Sourcepub fn set_network_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_network_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of network_uri.
Example
ⓘ
let x = RedisInstanceInfo::new().set_network_uri("example");Sourcepub fn set_primary_endpoint_ip<T: Into<String>>(self, v: T) -> Self
pub fn set_primary_endpoint_ip<T: Into<String>>(self, v: T) -> Self
Sets the value of primary_endpoint_ip.
Example
ⓘ
let x = RedisInstanceInfo::new().set_primary_endpoint_ip("example");Sourcepub fn set_read_endpoint_ip<T: Into<String>>(self, v: T) -> Self
pub fn set_read_endpoint_ip<T: Into<String>>(self, v: T) -> Self
Sets the value of read_endpoint_ip.
Example
ⓘ
let x = RedisInstanceInfo::new().set_read_endpoint_ip("example");Trait Implementations
Sourceimpl Clone for RedisInstanceInfo
impl Clone for RedisInstanceInfo
Sourcefn clone(&self) -> RedisInstanceInfo
fn clone(&self) -> RedisInstanceInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RedisInstanceInfo
impl Debug for RedisInstanceInfo
Sourceimpl Default for RedisInstanceInfo
impl Default for RedisInstanceInfo
Sourcefn default() -> RedisInstanceInfo
fn default() -> RedisInstanceInfo
Returns the “default value” for a type. Read more
Sourceimpl Message for RedisInstanceInfo
impl Message for RedisInstanceInfo
Sourceimpl PartialEq for RedisInstanceInfo
impl PartialEq for RedisInstanceInfo
Sourcefn eq(&self, other: &RedisInstanceInfo) -> bool
fn eq(&self, other: &RedisInstanceInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RedisInstanceInfo