RouteInfo

Struct RouteInfo 

#[non_exhaustive]
pub struct RouteInfo {
Show 24 fields pub route_type: RouteType, pub next_hop_type: NextHopType, pub route_scope: RouteScope, pub display_name: String, pub uri: String, pub region: String, pub dest_ip_range: String, pub next_hop: String, pub network_uri: String, pub priority: i32, pub instance_tags: Vec<String>, pub src_ip_range: String, pub dest_port_ranges: Vec<String>, pub src_port_ranges: Vec<String>, pub protocols: Vec<String>, pub ncc_hub_uri: Option<String>, pub ncc_spoke_uri: Option<String>, pub advertised_route_source_router_uri: Option<String>, pub advertised_route_next_hop_uri: Option<String>, pub next_hop_uri: String, pub next_hop_network_uri: String, pub originating_route_uri: String, pub originating_route_display_name: String, pub ncc_hub_route_uri: String, /* private fields */
}
For display only. Metadata associated with a Compute Engine route.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
route_type: RouteType

Type of route.

next_hop_type: NextHopType

Type of next hop.

route_scope: RouteScope
👎Deprecated

Indicates where route is applicable. Deprecated, routes with NCC_HUB scope are not included in the trace in new tests.

display_name: String

Name of a route.

uri: String

URI of a route. SUBNET, STATIC, PEERING_SUBNET (only for peering network) and POLICY_BASED routes only.

region: String

Region of the route. DYNAMIC, PEERING_DYNAMIC, POLICY_BASED and ADVERTISED routes only. If set for POLICY_BASED route, this is a region of VLAN attachments for Cloud Interconnect the route applies to. If set to “all” for POLICY_BASED route, the route applies to VLAN attachments of Cloud Interconnect in all regions.

dest_ip_range: String

Destination IP range of the route.

next_hop: String
👎Deprecated

String type of the next hop of the route (for example, “VPN tunnel”). Deprecated in favor of the next_hop_type and next_hop_uri fields, not used in new tests.

network_uri: String

URI of a VPC network where route is located.

priority: i32

Priority of the route.

instance_tags: Vec<String>

Instance tags of the route.

src_ip_range: String

Source IP address range of the route. POLICY_BASED routes only.

dest_port_ranges: Vec<String>

Destination port ranges of the route. POLICY_BASED routes only.

src_port_ranges: Vec<String>

Source port ranges of the route. POLICY_BASED routes only.

protocols: Vec<String>

Protocols of the route. POLICY_BASED routes only.

ncc_hub_uri: Option<String>

URI of the NCC Hub the route is advertised by. PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub only.

ncc_spoke_uri: Option<String>

URI of the destination NCC Spoke. PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub only.

advertised_route_source_router_uri: Option<String>

For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the corresponding IP prefix.

advertised_route_next_hop_uri: Option<String>
👎Deprecated

For ADVERTISED routes, the URI of their next hop, i.e. the URI of the hybrid endpoint (VPN tunnel, Interconnect attachment, NCC router appliance) the advertised prefix is advertised through, or URI of the source peered network. Deprecated in favor of the next_hop_uri field, not used in new tests.

next_hop_uri: String

URI of the next hop resource.

next_hop_network_uri: String

URI of a VPC network where the next hop resource is located.

originating_route_uri: String

For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating SUBNET/STATIC route.

originating_route_display_name: String

For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the originating SUBNET/STATIC/DYNAMIC route.

ncc_hub_route_uri: String

For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub, the URI of the corresponding route in NCC Hub’s routing table.

Implementations

Source

impl RouteInfo

pub fn new() -> Self

Creates a new default instance.

pub fn set_route_type<T: Into<RouteType>>(self, v: T) -> Self

Sets the value of route_type.

Example
use google_cloud_networkmanagement_v1::model::route_info::RouteType;
let x0 = RouteInfo::new().set_route_type(RouteType::Subnet);
let x1 = RouteInfo::new().set_route_type(RouteType::Static);
let x2 = RouteInfo::new().set_route_type(RouteType::Dynamic);
pub fn set_next_hop_type<T: Into<NextHopType>>(self, v: T) -> Self

Sets the value of next_hop_type.

Example
use google_cloud_networkmanagement_v1::model::route_info::NextHopType;
let x0 = RouteInfo::new().set_next_hop_type(NextHopType::NextHopIp);
let x1 = RouteInfo::new().set_next_hop_type(NextHopType::NextHopInstance);
let x2 = RouteInfo::new().set_next_hop_type(NextHopType::NextHopNetwork);
pub fn set_route_scope<T: Into<RouteScope>>(self, v: T) -> Self

👎Deprecated

Sets the value of route_scope.

Example
use google_cloud_networkmanagement_v1::model::route_info::RouteScope;
let x0 = RouteInfo::new().set_route_scope(RouteScope::Network);
let x1 = RouteInfo::new().set_route_scope(RouteScope::NccHub);
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = RouteInfo::new().set_display_name("example");
pub fn set_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of uri.

Example
let x = RouteInfo::new().set_uri("example");
pub fn set_region<T: Into<String>>(self, v: T) -> Self

Sets the value of region.

Example
let x = RouteInfo::new().set_region("example");
pub fn set_dest_ip_range<T: Into<String>>(self, v: T) -> Self

Sets the value of dest_ip_range.

Example
let x = RouteInfo::new().set_dest_ip_range("example");
pub fn set_next_hop<T: Into<String>>(self, v: T) -> Self

👎Deprecated

Sets the value of next_hop.

Example
let x = RouteInfo::new().set_next_hop("example");
pub fn set_network_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of network_uri.

Example
let x = RouteInfo::new().set_network_uri("example");
pub fn set_priority<T: Into<i32>>(self, v: T) -> Self

Sets the value of priority.

Example
let x = RouteInfo::new().set_priority(42);
pub fn set_instance_tags<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of instance_tags.

Example
let x = RouteInfo::new().set_instance_tags(["a", "b", "c"]);
pub fn set_src_ip_range<T: Into<String>>(self, v: T) -> Self

Sets the value of src_ip_range.

Example
let x = RouteInfo::new().set_src_ip_range("example");
pub fn set_dest_port_ranges<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of dest_port_ranges.

Example
let x = RouteInfo::new().set_dest_port_ranges(["a", "b", "c"]);
pub fn set_src_port_ranges<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of src_port_ranges.

Example
let x = RouteInfo::new().set_src_port_ranges(["a", "b", "c"]);
pub fn set_protocols<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of protocols.

Example
let x = RouteInfo::new().set_protocols(["a", "b", "c"]);
pub fn set_ncc_hub_uri<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of ncc_hub_uri.

Example
let x = RouteInfo::new().set_ncc_hub_uri("example");
pub fn set_or_clear_ncc_hub_uri<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of ncc_hub_uri.

Example
let x = RouteInfo::new().set_or_clear_ncc_hub_uri(Some("example"));
let x = RouteInfo::new().set_or_clear_ncc_hub_uri(None::<String>);
pub fn set_ncc_spoke_uri<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of ncc_spoke_uri.

Example
let x = RouteInfo::new().set_ncc_spoke_uri("example");
pub fn set_or_clear_ncc_spoke_uri<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of ncc_spoke_uri.

Example
let x = RouteInfo::new().set_or_clear_ncc_spoke_uri(Some("example"));
let x = RouteInfo::new().set_or_clear_ncc_spoke_uri(None::<String>);
pub fn set_advertised_route_source_router_uri<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of advertised_route_source_router_uri.

Example
let x = RouteInfo::new().set_advertised_route_source_router_uri("example");
pub fn set_or_clear_advertised_route_source_router_uri<T>( self, v: Option<T>, ) -> Self
where T: Into<String>,

Sets or clears the value of advertised_route_source_router_uri.

Example
let x = RouteInfo::new().set_or_clear_advertised_route_source_router_uri(Some("example"));
let x = RouteInfo::new().set_or_clear_advertised_route_source_router_uri(None::<String>);
pub fn set_advertised_route_next_hop_uri<T>(self, v: T) -> Self
where T: Into<String>,

👎Deprecated

Sets the value of advertised_route_next_hop_uri.

Example
let x = RouteInfo::new().set_advertised_route_next_hop_uri("example");
pub fn set_or_clear_advertised_route_next_hop_uri<T>(self, v: Option<T>) -> Self
where T: Into<String>,

👎Deprecated

Sets or clears the value of advertised_route_next_hop_uri.

Example
let x = RouteInfo::new().set_or_clear_advertised_route_next_hop_uri(Some("example"));
let x = RouteInfo::new().set_or_clear_advertised_route_next_hop_uri(None::<String>);
pub fn set_next_hop_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of next_hop_uri.

Example
let x = RouteInfo::new().set_next_hop_uri("example");
pub fn set_next_hop_network_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of next_hop_network_uri.

Example
let x = RouteInfo::new().set_next_hop_network_uri("example");
pub fn set_originating_route_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of originating_route_uri.

Example
let x = RouteInfo::new().set_originating_route_uri("example");
pub fn set_originating_route_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of originating_route_display_name.

Example
let x = RouteInfo::new().set_originating_route_display_name("example");
pub fn set_ncc_hub_route_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of ncc_hub_route_uri.

Example
let x = RouteInfo::new().set_ncc_hub_route_uri("example");