#[non_exhaustive]pub struct ShowEffectiveFlowLogsConfigsRequest {
pub parent: String,
pub resource: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request for the ShowEffectiveFlowLogsConfigs method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource of the VpcFlowLogsConfig, specified in
the following format: projects/{project_id}/locations/global
resource: StringRequired. The resource to get the effective VPC Flow Logs configuration for. The resource must belong to the same project as the parent. The resource must be a network, subnetwork, interconnect attachment, VPN tunnel, or a project.
page_size: i32Optional. Number of EffectiveVpcFlowLogsConfigs to return. Default is 30.
page_token: StringOptional. Page token from an earlier query, as returned in
next_page_token.
filter: StringOptional. Lists the EffectiveVpcFlowLogsConfigs that match the filter
expression. A filter expression must use the supported [CEL logic
operators]
(https://cloud.google.com/vpc/docs/about-flow-logs-records#supported_cel_logic_operators).
Implementations
Sourceimpl ShowEffectiveFlowLogsConfigsRequest
impl ShowEffectiveFlowLogsConfigsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_resource<T: Into<String>>(self, v: T) -> Self
pub fn set_resource<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ShowEffectiveFlowLogsConfigsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ShowEffectiveFlowLogsConfigsRequest
impl Clone for ShowEffectiveFlowLogsConfigsRequest
Sourcefn clone(&self) -> ShowEffectiveFlowLogsConfigsRequest
fn clone(&self) -> ShowEffectiveFlowLogsConfigsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ShowEffectiveFlowLogsConfigsRequest
impl Default for ShowEffectiveFlowLogsConfigsRequest
Sourcefn default() -> ShowEffectiveFlowLogsConfigsRequest
fn default() -> ShowEffectiveFlowLogsConfigsRequest
Sourceimpl PartialEq for ShowEffectiveFlowLogsConfigsRequest
impl PartialEq for ShowEffectiveFlowLogsConfigsRequest
Sourcefn eq(&self, other: &ShowEffectiveFlowLogsConfigsRequest) -> bool
fn eq(&self, other: &ShowEffectiveFlowLogsConfigsRequest) -> bool
self and other values to be equal, and is used by ==.