#[non_exhaustive]pub struct ShowEffectiveFlowLogsConfigsResponse {
pub effective_flow_logs_configs: Vec<EffectiveVpcFlowLogsConfig>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response for the ShowEffectiveFlowLogsConfigs method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.effective_flow_logs_configs: Vec<EffectiveVpcFlowLogsConfig>List of Effective Vpc Flow Logs configurations.
next_page_token: StringPage token to fetch the next set of configurations.
unreachable: Vec<String>Locations that could not be reached (when querying all locations with -).
Implementations
Sourceimpl ShowEffectiveFlowLogsConfigsResponse
impl ShowEffectiveFlowLogsConfigsResponse
Sourcepub fn set_effective_flow_logs_configs<T, V>(self, v: T) -> Self
pub fn set_effective_flow_logs_configs<T, V>(self, v: T) -> Self
Sets the value of effective_flow_logs_configs.
Example
ⓘ
use google_cloud_networkmanagement_v1::model::EffectiveVpcFlowLogsConfig;
let x = ShowEffectiveFlowLogsConfigsResponse::new()
.set_effective_flow_logs_configs([
EffectiveVpcFlowLogsConfig::default()/* use setters */,
EffectiveVpcFlowLogsConfig::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ShowEffectiveFlowLogsConfigsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ShowEffectiveFlowLogsConfigsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ShowEffectiveFlowLogsConfigsResponse
impl Clone for ShowEffectiveFlowLogsConfigsResponse
Sourcefn clone(&self) -> ShowEffectiveFlowLogsConfigsResponse
fn clone(&self) -> ShowEffectiveFlowLogsConfigsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ShowEffectiveFlowLogsConfigsResponse
impl Default for ShowEffectiveFlowLogsConfigsResponse
Sourcefn default() -> ShowEffectiveFlowLogsConfigsResponse
fn default() -> ShowEffectiveFlowLogsConfigsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ShowEffectiveFlowLogsConfigsResponse
impl PartialEq for ShowEffectiveFlowLogsConfigsResponse
Sourcefn eq(&self, other: &ShowEffectiveFlowLogsConfigsResponse) -> bool
fn eq(&self, other: &ShowEffectiveFlowLogsConfigsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ShowEffectiveFlowLogsConfigsResponse