#[non_exhaustive]pub struct UpdateVpcFlowLogsConfigRequest {
pub update_mask: Option<FieldMask>,
pub vpc_flow_logs_config: Option<VpcFlowLogsConfig>,
/* private fields */
}Expand description
Request for the UpdateVpcFlowLogsConfig method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Required. Mask of fields to update. At least one path must be supplied in
this field.
For example, to change the state of the configuration to ENABLED, specify
update_mask = "state", and the vpc_flow_logs_config would be:
vpc_flow_logs_config = { name = "projects/my-project/locations/global/vpcFlowLogsConfigs/my-config" state = "ENABLED" }
vpc_flow_logs_config: Option<VpcFlowLogsConfig>Required. Only fields specified in update_mask are updated.
Implementations
Sourceimpl UpdateVpcFlowLogsConfigRequest
impl UpdateVpcFlowLogsConfigRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateVpcFlowLogsConfigRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateVpcFlowLogsConfigRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateVpcFlowLogsConfigRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_vpc_flow_logs_config<T>(self, v: T) -> Selfwhere
T: Into<VpcFlowLogsConfig>,
pub fn set_vpc_flow_logs_config<T>(self, v: T) -> Selfwhere
T: Into<VpcFlowLogsConfig>,
Sets the value of vpc_flow_logs_config.
Example
ⓘ
use google_cloud_networkmanagement_v1::model::VpcFlowLogsConfig;
let x = UpdateVpcFlowLogsConfigRequest::new().set_vpc_flow_logs_config(VpcFlowLogsConfig::default()/* use setters */);Sourcepub fn set_or_clear_vpc_flow_logs_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<VpcFlowLogsConfig>,
pub fn set_or_clear_vpc_flow_logs_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<VpcFlowLogsConfig>,
Sets or clears the value of vpc_flow_logs_config.
Example
ⓘ
use google_cloud_networkmanagement_v1::model::VpcFlowLogsConfig;
let x = UpdateVpcFlowLogsConfigRequest::new().set_or_clear_vpc_flow_logs_config(Some(VpcFlowLogsConfig::default()/* use setters */));
let x = UpdateVpcFlowLogsConfigRequest::new().set_or_clear_vpc_flow_logs_config(None::<VpcFlowLogsConfig>);Trait Implementations
Sourceimpl Clone for UpdateVpcFlowLogsConfigRequest
impl Clone for UpdateVpcFlowLogsConfigRequest
Sourcefn clone(&self) -> UpdateVpcFlowLogsConfigRequest
fn clone(&self) -> UpdateVpcFlowLogsConfigRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateVpcFlowLogsConfigRequest
impl Default for UpdateVpcFlowLogsConfigRequest
Sourcefn default() -> UpdateVpcFlowLogsConfigRequest
fn default() -> UpdateVpcFlowLogsConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateVpcFlowLogsConfigRequest
impl PartialEq for UpdateVpcFlowLogsConfigRequest
Sourcefn eq(&self, other: &UpdateVpcFlowLogsConfigRequest) -> bool
fn eq(&self, other: &UpdateVpcFlowLogsConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateVpcFlowLogsConfigRequest