#[non_exhaustive]pub enum StepInfo {
Show 36 variants
Instance(Box<InstanceInfo>),
Firewall(Box<FirewallInfo>),
Route(Box<RouteInfo>),
Endpoint(Box<EndpointInfo>),
GoogleService(Box<GoogleServiceInfo>),
ForwardingRule(Box<ForwardingRuleInfo>),
HybridSubnet(Box<HybridSubnetInfo>),
VpnGateway(Box<VpnGatewayInfo>),
VpnTunnel(Box<VpnTunnelInfo>),
InterconnectAttachment(Box<InterconnectAttachmentInfo>),
VpcConnector(Box<VpcConnectorInfo>),
DirectVpcEgressConnection(Box<DirectVpcEgressConnectionInfo>),
ServerlessExternalConnection(Box<ServerlessExternalConnectionInfo>),
Deliver(Box<DeliverInfo>),
Forward(Box<ForwardInfo>),
Abort(Box<AbortInfo>),
Drop(Box<DropInfo>),
LoadBalancer(Box<LoadBalancerInfo>),
Network(Box<NetworkInfo>),
GkeMaster(Box<GKEMasterInfo>),
GkePod(Box<GkePodInfo>),
IpMasqueradingSkipped(Box<IpMasqueradingSkippedInfo>),
GkeNetworkPolicy(Box<GkeNetworkPolicyInfo>),
GkeNetworkPolicySkipped(Box<GkeNetworkPolicySkippedInfo>),
CloudSqlInstance(Box<CloudSQLInstanceInfo>),
RedisInstance(Box<RedisInstanceInfo>),
RedisCluster(Box<RedisClusterInfo>),
CloudFunction(Box<CloudFunctionInfo>),
AppEngineVersion(Box<AppEngineVersionInfo>),
CloudRunRevision(Box<CloudRunRevisionInfo>),
Nat(Box<NatInfo>),
ProxyConnection(Box<ProxyConnectionInfo>),
LoadBalancerBackendInfo(Box<LoadBalancerBackendInfo>),
StorageBucket(Box<StorageBucketInfo>),
ServerlessNeg(Box<ServerlessNegInfo>),
NgfwPacketInspection(Box<NgfwPacketInspectionInfo>),
}Expand description
Configuration or metadata associated with each step. The configuration is filtered based on viewer’s permission. If a viewer has no permission to view the configuration in this step, for non-final states a special state is populated (VIEWER_PERMISSION_MISSING), and for final state the configuration is cleared.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Instance(Box<InstanceInfo>)
Display information of a Compute Engine instance.
Firewall(Box<FirewallInfo>)
Display information of a Compute Engine firewall rule.
Route(Box<RouteInfo>)
Display information of a Compute Engine route.
Endpoint(Box<EndpointInfo>)
Display information of the source and destination under analysis. The endpoint information in an intermediate state may differ with the initial input, as it might be modified by state like NAT, or Connection Proxy.
GoogleService(Box<GoogleServiceInfo>)
Display information of a Google service
ForwardingRule(Box<ForwardingRuleInfo>)
Display information of a Compute Engine forwarding rule.
HybridSubnet(Box<HybridSubnetInfo>)
Display information of a hybrid subnet.
VpnGateway(Box<VpnGatewayInfo>)
Display information of a Compute Engine VPN gateway.
VpnTunnel(Box<VpnTunnelInfo>)
Display information of a Compute Engine VPN tunnel.
InterconnectAttachment(Box<InterconnectAttachmentInfo>)
Display information of an interconnect attachment.
VpcConnector(Box<VpcConnectorInfo>)
Display information of a VPC connector.
DirectVpcEgressConnection(Box<DirectVpcEgressConnectionInfo>)
Display information of a serverless direct VPC egress connection.
ServerlessExternalConnection(Box<ServerlessExternalConnectionInfo>)
Display information of a serverless public (external) connection.
Deliver(Box<DeliverInfo>)
Display information of the final state “deliver” and reason.
Forward(Box<ForwardInfo>)
Display information of the final state “forward” and reason.
Abort(Box<AbortInfo>)
Display information of the final state “abort” and reason.
Drop(Box<DropInfo>)
Display information of the final state “drop” and reason.
LoadBalancer(Box<LoadBalancerInfo>)
Display information of the load balancers. Deprecated in favor of the
load_balancer_backend_info field, not used in new tests.
Network(Box<NetworkInfo>)
Display information of a Google Cloud network.
GkeMaster(Box<GKEMasterInfo>)
Display information of a Google Kubernetes Engine cluster master.
GkePod(Box<GkePodInfo>)
Display information of a Google Kubernetes Engine Pod.
IpMasqueradingSkipped(Box<IpMasqueradingSkippedInfo>)
Display information of the reason why GKE Pod IP masquerading was skipped.
GkeNetworkPolicy(Box<GkeNetworkPolicyInfo>)
Display information of a GKE Network Policy.
GkeNetworkPolicySkipped(Box<GkeNetworkPolicySkippedInfo>)
Display information of the reason why GKE Network Policy evaluation was skipped.
CloudSqlInstance(Box<CloudSQLInstanceInfo>)
Display information of a Cloud SQL instance.
RedisInstance(Box<RedisInstanceInfo>)
Display information of a Redis Instance.
RedisCluster(Box<RedisClusterInfo>)
Display information of a Redis Cluster.
CloudFunction(Box<CloudFunctionInfo>)
Display information of a Cloud Function.
AppEngineVersion(Box<AppEngineVersionInfo>)
Display information of an App Engine service version.
CloudRunRevision(Box<CloudRunRevisionInfo>)
Display information of a Cloud Run revision.
Nat(Box<NatInfo>)
Display information of a NAT.
ProxyConnection(Box<ProxyConnectionInfo>)
Display information of a ProxyConnection.
LoadBalancerBackendInfo(Box<LoadBalancerBackendInfo>)
Display information of a specific load balancer backend.
StorageBucket(Box<StorageBucketInfo>)
Display information of a Storage Bucket. Used only for return traces.
ServerlessNeg(Box<ServerlessNegInfo>)
Display information of a Serverless network endpoint group backend. Used only for return traces.
NgfwPacketInspection(Box<NgfwPacketInspectionInfo>)
Display information of a layer 7 packet inspection by the firewall.