#[non_exhaustive]pub struct EndpointInfo {
pub source_ip: String,
pub destination_ip: String,
pub protocol: String,
pub source_port: i32,
pub destination_port: i32,
pub source_network_uri: String,
pub destination_network_uri: String,
pub source_agent_uri: String,
/* private fields */
}Expand description
For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_ip: StringSource IP address.
destination_ip: StringDestination IP address.
protocol: StringIP protocol in string format, for example: “TCP”, “UDP”, “ICMP”.
source_port: i32Source port. Only valid when protocol is TCP or UDP.
destination_port: i32Destination port. Only valid when protocol is TCP or UDP.
source_network_uri: StringURI of the network where this packet originates from.
destination_network_uri: StringURI of the network where this packet is sent to.
source_agent_uri: StringURI of the source telemetry agent this packet originates from.
Implementations
Sourceimpl EndpointInfo
impl EndpointInfo
Sourcepub fn set_source_ip<T: Into<String>>(self, v: T) -> Self
pub fn set_source_ip<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_destination_ip<T: Into<String>>(self, v: T) -> Self
pub fn set_destination_ip<T: Into<String>>(self, v: T) -> Self
Sets the value of destination_ip.
Example
ⓘ
let x = EndpointInfo::new().set_destination_ip("example");Sourcepub fn set_protocol<T: Into<String>>(self, v: T) -> Self
pub fn set_protocol<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_source_port<T: Into<i32>>(self, v: T) -> Self
pub fn set_source_port<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_destination_port<T: Into<i32>>(self, v: T) -> Self
pub fn set_destination_port<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_source_network_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_source_network_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of source_network_uri.
Example
ⓘ
let x = EndpointInfo::new().set_source_network_uri("example");Sourcepub fn set_destination_network_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_destination_network_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of destination_network_uri.
Example
ⓘ
let x = EndpointInfo::new().set_destination_network_uri("example");Sourcepub fn set_source_agent_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_source_agent_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of source_agent_uri.
Example
ⓘ
let x = EndpointInfo::new().set_source_agent_uri("example");Trait Implementations
Sourceimpl Clone for EndpointInfo
impl Clone for EndpointInfo
Sourcefn clone(&self) -> EndpointInfo
fn clone(&self) -> EndpointInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointInfo
impl Debug for EndpointInfo
Sourceimpl Default for EndpointInfo
impl Default for EndpointInfo
Sourcefn default() -> EndpointInfo
fn default() -> EndpointInfo
Returns the “default value” for a type. Read more
Sourceimpl Message for EndpointInfo
impl Message for EndpointInfo
Sourceimpl PartialEq for EndpointInfo
impl PartialEq for EndpointInfo
Sourcefn eq(&self, other: &EndpointInfo) -> bool
fn eq(&self, other: &EndpointInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EndpointInfo