#[non_exhaustive]pub struct LoadBalancerBackendInfo {
pub name: String,
pub instance_uri: String,
pub backend_service_uri: String,
pub instance_group_uri: String,
pub network_endpoint_group_uri: String,
pub backend_bucket_uri: String,
pub psc_service_attachment_uri: String,
pub psc_google_api_target: String,
pub health_check_uri: String,
pub health_check_firewalls_config_state: HealthCheckFirewallsConfigState,
/* private fields */
}Expand description
For display only. Metadata associated with the load balancer backend.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringDisplay name of the backend. For example, it might be an instance name for the instance group backends, or an IP address and port for zonal network endpoint group backends.
instance_uri: StringURI of the backend instance (if applicable). Populated for instance group backends, and zonal NEG backends.
backend_service_uri: StringURI of the backend service this backend belongs to (if applicable).
instance_group_uri: StringURI of the instance group this backend belongs to (if applicable).
network_endpoint_group_uri: StringURI of the network endpoint group this backend belongs to (if applicable).
backend_bucket_uri: StringURI of the backend bucket this backend targets (if applicable).
psc_service_attachment_uri: StringURI of the PSC service attachment this PSC NEG backend targets (if applicable).
psc_google_api_target: StringPSC Google API target this PSC NEG backend targets (if applicable).
health_check_uri: StringURI of the health check attached to this backend (if applicable).
health_check_firewalls_config_state: HealthCheckFirewallsConfigStateOutput only. Health check firewalls configuration state for the backend. This is a result of the static firewall analysis (verifying that health check traffic from required IP ranges to the backend is allowed or not). The backend might still be unhealthy even if these firewalls are configured. Please refer to the documentation for more information: https://cloud.google.com/load-balancing/docs/firewall-rules
Implementations
Sourceimpl LoadBalancerBackendInfo
impl LoadBalancerBackendInfo
Sourcepub fn set_instance_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_instance_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of instance_uri.
Example
let x = LoadBalancerBackendInfo::new().set_instance_uri("example");Sourcepub fn set_backend_service_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_backend_service_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of backend_service_uri.
Example
let x = LoadBalancerBackendInfo::new().set_backend_service_uri("example");Sourcepub fn set_instance_group_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_instance_group_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of instance_group_uri.
Example
let x = LoadBalancerBackendInfo::new().set_instance_group_uri("example");Sourcepub fn set_network_endpoint_group_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_network_endpoint_group_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of network_endpoint_group_uri.
Example
let x = LoadBalancerBackendInfo::new().set_network_endpoint_group_uri("example");Sourcepub fn set_backend_bucket_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_backend_bucket_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of backend_bucket_uri.
Example
let x = LoadBalancerBackendInfo::new().set_backend_bucket_uri("example");Sourcepub fn set_psc_service_attachment_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_psc_service_attachment_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of psc_service_attachment_uri.
Example
let x = LoadBalancerBackendInfo::new().set_psc_service_attachment_uri("example");Sourcepub fn set_psc_google_api_target<T: Into<String>>(self, v: T) -> Self
pub fn set_psc_google_api_target<T: Into<String>>(self, v: T) -> Self
Sets the value of psc_google_api_target.
Example
let x = LoadBalancerBackendInfo::new().set_psc_google_api_target("example");Sourcepub fn set_health_check_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_health_check_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of health_check_uri.
Example
let x = LoadBalancerBackendInfo::new().set_health_check_uri("example");Sourcepub fn set_health_check_firewalls_config_state<T: Into<HealthCheckFirewallsConfigState>>(
self,
v: T,
) -> Self
pub fn set_health_check_firewalls_config_state<T: Into<HealthCheckFirewallsConfigState>>( self, v: T, ) -> Self
Sets the value of health_check_firewalls_config_state.
Example
use google_cloud_networkmanagement_v1::model::load_balancer_backend_info::HealthCheckFirewallsConfigState;
let x0 = LoadBalancerBackendInfo::new().set_health_check_firewalls_config_state(HealthCheckFirewallsConfigState::FirewallsConfigured);
let x1 = LoadBalancerBackendInfo::new().set_health_check_firewalls_config_state(HealthCheckFirewallsConfigState::FirewallsPartiallyConfigured);
let x2 = LoadBalancerBackendInfo::new().set_health_check_firewalls_config_state(HealthCheckFirewallsConfigState::FirewallsNotConfigured);Trait Implementations
Sourceimpl Clone for LoadBalancerBackendInfo
impl Clone for LoadBalancerBackendInfo
Sourcefn clone(&self) -> LoadBalancerBackendInfo
fn clone(&self) -> LoadBalancerBackendInfo
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for LoadBalancerBackendInfo
impl Debug for LoadBalancerBackendInfo
Sourceimpl Default for LoadBalancerBackendInfo
impl Default for LoadBalancerBackendInfo
Sourcefn default() -> LoadBalancerBackendInfo
fn default() -> LoadBalancerBackendInfo
Sourceimpl Message for LoadBalancerBackendInfo
impl Message for LoadBalancerBackendInfo
Sourceimpl PartialEq for LoadBalancerBackendInfo
impl PartialEq for LoadBalancerBackendInfo
Sourcefn eq(&self, other: &LoadBalancerBackendInfo) -> bool
fn eq(&self, other: &LoadBalancerBackendInfo) -> bool
self and other values to be equal, and is used by ==.